@@ -2,8 +2,8 @@ from collections import OrderedDict
 import json
 from pathlib import Path
 
-from pynando.data import find
-
+from .data import find
+from .downloader import Downloader
 
 class NandoNode(object):
     def __init__(
@@ -82,7 +82,7 @@ class NandoNode(object):
 
 
 class Nando(object):
-    def __init__(self, resource_name: str):
+    def __init__(self, resource: str):
         self.root = NandoNode(
             _id='0',
             name_ja='root',
@@ -98,7 +98,10 @@ class Nando(object):
             obsolete=None,
         )
         self.nando_node_dict = {'0': self.root}
-        self.fp = find(resource_name)
+        self.fp = find(resource)
+        if not self.fp.exists():
+            downloader = Downloader()
+            downloader.download(resource)
         self.read(self.fp)
 
     def __len__(self):
